Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(67)

Unified Diff: content/gpu/gpu_child_thread.h

Issue 2420253002: Rename shell namespace to service_manager (Closed)
Patch Set: . Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/common/service_worker/embedded_worker_setup.mojom ('k') | content/gpu/gpu_child_thread.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/gpu/gpu_child_thread.h
diff --git a/content/gpu/gpu_child_thread.h b/content/gpu/gpu_child_thread.h
index 1ee30fa9003d87c73d5aa2de0b0d715fccd22525..3882fa526d254ce6886bdd9ae77b81ed21f32c7a 100644
--- a/content/gpu/gpu_child_thread.h
+++ b/content/gpu/gpu_child_thread.h
@@ -127,7 +127,8 @@ class GpuChildThread : public ChildThreadImpl,
#endif
void OnLoseAllContexts();
- void BindServiceFactoryRequest(shell::mojom::ServiceFactoryRequest request);
+ void BindServiceFactoryRequest(
+ service_manager::mojom::ServiceFactoryRequest request);
// Set this flag to true if a fatal error occurred before we receive the
// OnInitialize message, in which case we just declare ourselves DOA.
@@ -159,11 +160,12 @@ class GpuChildThread : public ChildThreadImpl,
// The gpu::GpuMemoryBufferFactory instance used to allocate GpuMemoryBuffers.
gpu::GpuMemoryBufferFactory* const gpu_memory_buffer_factory_;
// ServiceFactory for shell::Service hosting.
std::unique_ptr<GpuServiceFactory> service_factory_;
- // Bindings to the shell::mojom::ServiceFactory impl.
- mojo::BindingSet<shell::mojom::ServiceFactory> service_factory_bindings_;
+ // Bindings to the service_manager::mojom::ServiceFactory impl.
+ mojo::BindingSet<service_manager::mojom::ServiceFactory>
+ service_factory_bindings_;
DISALLOW_COPY_AND_ASSIGN(GpuChildThread);
};
« no previous file with comments | « content/common/service_worker/embedded_worker_setup.mojom ('k') | content/gpu/gpu_child_thread.cc » ('j') | no next file with comments »
@@ -159,11 +160,12 @@ class GpuChildThread : public ChildThreadImpl,
// The gpu::GpuMemoryBufferFactory instance used to allocate GpuMemoryBuffers.
gpu::GpuMemoryBufferFactory* const gpu_memory_buffer_factory_;
- // ServiceFactory for shell::Service hosting.
+ // ServiceFactory for service_manager::Service hosting.
std::unique_ptr<GpuServiceFactory> service_factory_;

Powered by Google App Engine
This is Rietveld 408576698